==> packageinstaller-pkglist-libre_0.1.4.tar.xz: packageinstaller-pkglist-libre/Basque_Thunderbird.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>  
Basque_Thunderbird
</name>

<description>  
   <am>Basque localisation of Thunderbird</am>
   <ar>Basque localisation of Thunderbird</ar>
   <bg>Basque localisation of Thunderbird</bg>
   <bn>Basque localisation of Thunderbird</bn>
   <ca>Localització de Thunderbird en Euskara</ca>
   <cs>Basque localisation of Thunderbird</cs>
   <da>Baskisk oversættelse af Thunderbird</da>
   <de>Baskische Lokalisierung von Thunderbird</de>
   <el>Basque εντοπισμός του Thunderbird</el>
   <en>Basque localisation of Thunderbird</en>
   <es>Localización Vasco de Thunderbird</es>
   <et>Basque localisation of Thunderbird</et>
   <eu>Basque localisation of Thunderbird</eu>
   <fa>Basque localisation of Thunderbird</fa>
   <fil_PH>Basque localisation of Thunderbird</fil_PH>
   <fi>Basque localisation of Thunderbird</fi>
   <fr>Localisation basque pour Thunderbird</fr>
   <he_IL>Basque localisation of Thunderbird</he_IL>
   <hi>Basque localisation of Thunderbird</hi>
   <hr>Baskijska lokalizacija Thunderbirda</hr>
   <hu>Basque localisation of Thunderbird</hu>
   <id>Basque localisation of Thunderbird</id>
   <is>Basque localisation of Thunderbird</is>
   <it>Localizzazione basca di Thunderbird</it>
   <ja_JP>Basque localisation of Thunderbird</ja_JP>
   <ja>Basque localisation of Thunderbird</ja>
   <kk>Basque localisation of Thunderbird</kk>
   <ko>Basque localisation of Thunderbird</ko>
   <lt>Basque localisation of Thunderbird</lt>
   <mk>Basque localisation of Thunderbird</mk>
   <mr>Basque localisation of Thunderbird</mr>
   <nb>Basque localisation of Thunderbird</nb>
   <nl>Baskische lokalisatie van Thunderbird</nl>
   <pl>Baskijska lokalizacja Thunderbirda</pl>
   <pt_BR>Basco Localização para Thunderbird</pt_BR>
   <pt>Basco Localização para Thunderbird</pt>
   <ro>Basque localisation of Thunderbird</ro>
   <ru>Basque localisation of Thunderbird</ru>
   <sk>Basque lokalizácia pre Thunderbird</sk>
   <sl>Basque localisation of Thunderbird</sl>
   <sq>Basque localisation of Thunderbird</sq>
   <sr>Basque localisation of Thunderbird</sr>
   <sv>Baskisk lokalisering av Thunderbird</sv>
   <tr>Thunderbird'ün Bask dili yerelleştirmesi</tr>
   <uk>Basque локалізація Thunderbird</uk>
   <vi>Basque localisation of Thunderbird</vi>
   <zh_CN>Basque localisation of Thunderbird</zh_CN>
   <zh_TW>Basque localisation of Thunderbird</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
thunderbird-l10n-eu
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
thunderbird-l10n-eu
</uninstall_package_names>

</app>

==> packageinstaller-pkglist-libre_0.1.7.tar.xz: packageinstaller-pkglist-libre/Basque_Thunderbird.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Basque_Thunderbird
</name>

<description>
   <am>Basque localisation of Thunderbird</am>
   <ar>Basque localisation of Thunderbird</ar>
   <be>Basque localisation of Thunderbird</be>
   <bg>Basque localisation of Thunderbird</bg>
   <bn>Basque localisation of Thunderbird</bn>
   <ca>Localització de Thunderbird en Euskara</ca>
   <cs>Basque localisation of Thunderbird</cs>
   <da>Baskisk oversættelse af Thunderbird</da>
   <de>Baskische Lokalisierung von Thunderbird</de>
   <el>Βασκικά για το Thunderbird</el>
   <en>Basque localisation of Thunderbird</en>
   <es_ES>Localización Eusquera de Thunderbird</es_ES>
   <es>Localización Vasco de Thunderbird</es>
   <et>Basque localisation of Thunderbird</et>
   <eu>Basque localisation of Thunderbird</eu>
   <fa>Basque localisation of Thunderbird</fa>
   <fil_PH>Basque localisation of Thunderbird</fil_PH>
   <fi>Baskilainen Thunderbird-kotoistus</fi>
   <fr_BE>Localisation en basque pour Thunderbird</fr_BE>
   <fr>Localisation en basque pour Thunderbird</fr>
   <gl_ES>Localización de Thunderbird para basco</gl_ES>
   <he_IL>Basque localisation of Thunderbird</he_IL>
   <hi>Basque localisation of Thunderbird</hi>
   <hr>Baskijska lokalizacija Thunderbirda</hr>
   <hu>Basque localisation of Thunderbird</hu>
   <id>Basque localisation of Thunderbird</id>
   <is>Basque localisation of Thunderbird</is>
   <it>Localizzazione basca di Thunderbird</it>
   <ja>バスク語版 Thunderbird</ja>
   <kk>Basque localisation of Thunderbird</kk>
   <ko>Basque localisation of Thunderbird</ko>
   <lt>Basque localisation of Thunderbird</lt>
   <mk>Basque localisation of Thunderbird</mk>
   <mr>Basque localisation of Thunderbird</mr>
   <nb_NO>Basque localisation of Thunderbird</nb_NO>
   <nb>Baskisk lokaltilpassing av Thunderbird</nb>
   <nl_BE>Basque localisation of Thunderbird</nl_BE>
   <nl>Baskische lokalisatie van Thunderbird</nl>
   <pl>Baskijska lokalizacja Thunderbirda</pl>
   <pt_BR>Basco Localização para o Thunderbird</pt_BR>
   <pt>Basco Localização para Thunderbird</pt>
   <ro>Basque localisation of Thunderbird</ro>
   <ru>Basque localisation of Thunderbird</ru>
   <sk>Basque lokalizácia pre Thunderbird</sk>
   <sl>Basque localisation of Thunderbird</sl>
   <sq>Basque localisation of Thunderbird</sq>
   <sr>Basque localisation of Thunderbird</sr>
   <sv>Baskisk lokalisering av Thunderbird</sv>
   <th>Basque localisation ของ Thunderbird</th>
   <tr>Thunderbird'ün Bask dili yerelleştirmesi</tr>
   <uk>Basque локалізація Thunderbird</uk>
   <vi>Basque localisation of Thunderbird</vi>
   <zh_CN>Thunderbird 巴斯克语语言包</zh_CN>
   <zh_HK>Basque localisation of Thunderbird</zh_HK>
   <zh_TW>Basque localisation of Thunderbird</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
thunderbird-l10n-eu
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
thunderbird-l10n-eu
</uninstall_package_names>

</app>
